import { BigNumberish } from "ethers";
/**
 * Error that may get thrown if IPFS returns nothing for a given uri.
 * @public
 */
export declare class NotFoundError extends Error {
    /** @internal */
    constructor(identifier?: string);
}
/**
 * Error that may get thrown if an invalid address was passed
 * @public
 */
export declare class InvalidAddressError extends Error {
    /** @internal */
    constructor(address?: string);
}
export declare class MissingRoleError extends Error {
    /** @internal */
    /** @internal */
    constructor(address: string, role: string);
}
export declare class AssetNotFoundError extends Error {
    /** @internal */
    /** @internal */
    constructor(message?: string);
}
export declare class UploadError extends Error {
    /** @internal */
    constructor(message: string);
}
export declare class FileNameMissingError extends Error {
    /** @internal */
    constructor();
}
export declare class DuplicateFileNameError extends Error {
    /** @internal */
    constructor(fileName: string);
}
export declare class NotEnoughTokensError extends Error {
    /** @internal */
    constructor(contractAddress: string, quantity: number, available: number);
}
export declare class MissingOwnerRoleError extends Error {
    /** @internal */
    constructor();
}
export declare class QuantityAboveLimitError extends Error {
    /** @internal */
    constructor(quantity: string);
}
/**
 * Thrown when data fails to fetch from storage.
 */
export declare class FetchError extends Error {
    innerError?: Error;
    /** @internal */
    constructor(message: string, innerError?: Error);
}
/**
 * Thrown when attempting to create a snapshot with duplicate leafs
 */
export declare class DuplicateLeafsError extends Error {
    constructor(message?: string);
}
/**
 * Thrown when attempting to update/cancel an auction that already started
 */
export declare class AuctionAlreadyStartedError extends Error {
    constructor(id?: string);
}
export declare class FunctionDeprecatedError extends Error {
    /** @internal */
    constructor(message: string);
}
/**
 * Thrown when trying to retrieve a listing from a marketplace that doesn't exist
 */
export declare class ListingNotFoundError extends Error {
    constructor(marketplaceContractAddress: string, listingId?: string);
}
/**
 * Thrown when trying to retrieve a listing of the wrong type
 */
export declare class WrongListingTypeError extends Error {
    constructor(marketplaceContractAddress: string, listingId?: string, actualType?: string, expectedType?: string);
}
/**
 * Thrown when attempting to transfer an asset that has restricted transferability
 */
export declare class RestrictedTransferError extends Error {
    constructor(assetAddress?: string);
}
/**
 * Thrown when attempting to execute an admin-role function.
 */
export declare class AdminRoleMissingError extends Error {
    constructor(address?: string, contractAddress?: string, message?: string);
}
/**
 * Thrown when attempting to close an auction that has not ended
 */
export declare class AuctionHasNotEndedError extends Error {
    constructor(id?: string, endTime?: BigNumberish);
}
